@@ -55,6 +55,13 @@ class TestURIReferenceParsesURIs(base.BaseTestParsesURIs):
         assert uri.userinfo is None
         assert uri.authority is None
 
+    def test_parses_ipv6_to_path(self):
+        """Verify that we don't parse [ as a scheme."""
+        uri = self.test_class.from_string('[::1]')
+        assert uri.scheme is None
+        assert uri.authority is None
+        assert uri.path == '[::1]'
+
 
 class TestURIValidation:
     # Valid URI tests
@@ -344,3 +351,15 @@ def test_empty_querystrings_persist():
     ref = URIReference.from_string(url)
     assert ref.query == ''
     assert ref.unsplit() == url
+
+
+def test_wide_domain_bypass_check():
+    """Verify we properly parse/handle the authority.
+
+    See also:
+    https://bugs.xdavidhu.me/google/2020/03/08/the-unexpected-google-wide-domain-check-bypass/
+    """
+    url = "https://user:pass@xdavidhu.me\\test.corp.google.com:8080/path/to/something?param=value#hash"
+    ref = URIReference.from_string(url)
+    assert ref.scheme == "https"
+    assert ref.host == "xdavidhu.me"
